InAppChatCore class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
constructFCMPayload({required User peer, required String message, required String token})
→ String
-
-
createClient()
→ Future<void>
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
getApnsTokens(User user)
→ Future<List<String>>
-
-
getUser(String userUid)
→ Future<User?>
-
Returns a stream of all users from Firebase
-
getUserByUserID(String userId)
→ Future<User?>
-
Returns a stream of all users from Firebase
-
getUserByUsername(String username)
→ Future<User?>
-
Returns a stream of all users from Firebase
-
log(Object o)
→ dynamic
-
-
login(String username, {required String firstName, required String lastName})
→ Future<void>
-
-
logout()
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
openChat(BuildContext context)
→ Future
-
-
openChatRoom(BuildContext context, Room room)
→ Future
-
-
openChatRoomByUser(BuildContext context, User peer)
→ Future
-
-
openChatRoomByUserID(BuildContext context, String userId)
→ Future
-
-
openChatRoomByUsername(BuildContext context, String username)
→ Future
-
-
openChatUser(BuildContext context)
→ Future
-
-
openTestChat(BuildContext context)
→ Future
-
-
register(String username, {required String firstName, required String lastName})
→ Future<void>
-
-
registerAppId(AppId appId)
→ dynamic
-
-
registerAuthorization(String token)
→ dynamic
-
-
registerDevice()
→ dynamic
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendPushMessage({required User peer, required String message})
→ Future<void>
-
-
sendPushMessageToFCMToken({required User peer, required String message, required String token})
→ dynamic
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateDeviceToken()
→ dynamic
-